==> nebula-core-1.2.3.10-Release-sources.jar: com/bizunited/platform/core/common/constant/DataViewSystemParamKey.java <==
package com.bizunited.platform.core.common.constant;

/**
 * 用于视图预置值的标识
 * 参见DataViewSystemEntity的paramKey
 */
public class DataViewSystemParamKey {

  private DataViewSystemParamKey(){}

  /** 操作者用户ID*/
  public static final String OPT_USER_ID = "userId";
  /** 操作者用户名*/
  public static final String OPT_USER_NAME = "userName";
  /** 操作者账户*/
  public static final String OPT_USER_ACCOUNT = "userAccount";
  /** 操作者编码*/
  public static final String OPT_USER_CODE = "userCode";
  /** 操作者手机号*/
  public static final String OPT_USER_PHONE = "userPhone";
  /** 操作者用户状态*/
  public static final String OPT_USER_STATUS = "userStatus";
  /** 操作者用户身份证号码*/
  public static final String OPT_USER_IDCARD = "userIdcard";


  /** 操作者所在岗位ID*/
  public static final String OPT_USER_POSITION_ID = "userPositionId";
  /** 操作者所在岗位*/
  public static final String OPT_USER_POSITION = "userPosition";
  /** 操作者岗位编码*/
  public static final String OPT_USER_POSITION_CODE = "userPositionCode";
  /** 操作者岗位状态*/
  public static final String OPT_USER_POSITION_STATUS = "userPositionStatus";


  /** 操作者所在组织机构ID*/
  public static final String OPT_USER_ORG_ID = "userOrgId";
  /** 操作者所在组织机构*/
  public static final String OPT_USER_ORG = "userOrg";
  /** 操作者所在组织机构类型*/
  public static final String OPT_USER_ORG_TYPE = "userOrgType";
  /** 操作者所在组织机构描述*/
  public static final String OPT_USER_ORG_DESC = "userOrgDesc";
  /** 操作者所在组织机构状态*/
  public static final String OPT_USER_ORG_STATUS = "userOrgStatus";


  /** 操作者所在用户组*/
  public static final String OPT_USER_GROUP = "userGroup";
  /** 操作者所属角色*/
  public static final String OPT_USER_ROLE = "userRole";



  /** 当前时间（当前月）*/
  public static final String NOW_DATE_MONTH = "nowDateMonth";
  /** 当前时间（当前日）*/
  public static final String NOW_DATE_DAY = "nowDateDay";
  /** 当前时间（精确到秒）*/
  public static final String NOW_DATE_SECOND = "nowDateSecond";
  /** 当前时间（精确到分）*/
  public static final String NOW_DATE_MINUTE = "nowDateMinute";


  /** 当前操作者登录时间*/
  public static final String CURRENT_USER_LOGIN_TIME = "currentUserLoginTime";
  /** 当前操作者最后登出时间*/
  public static final String CURRENT_USER_LOG_OUT_TIME = "currentUserLogOutTime";

}

==> nebula-core-2.0.2.23-Release-sources.jar: com/bizunited/platform/core/common/constant/DataViewSystemParamKey.java <==
package com.bizunited.platform.core.common.constant;

/**
 * 用于视图预置值的标识
 * 参见DataViewSystemEntity的paramKey
 */
public class DataViewSystemParamKey {

  private DataViewSystemParamKey(){}

  /** 操作者用户ID*/
  public static final String OPT_USER_ID = "userId";
  /** 操作者用户名*/
  public static final String OPT_USER_NAME = "userName";
  /** 操作者账户*/
  public static final String OPT_USER_ACCOUNT = "userAccount";
  /** 操作者编码*/
  public static final String OPT_USER_CODE = "userCode";
  /** 操作者手机号*/
  public static final String OPT_USER_PHONE = "userPhone";
  /** 操作者用户状态*/
  public static final String OPT_USER_STATUS = "userStatus";
  /** 操作者用户身份证号码*/
  public static final String OPT_USER_IDCARD = "userIdcard";


  /** 操作者所在岗位ID*/
  public static final String OPT_USER_POSITION_ID = "userPositionId";
  /** 操作者所在岗位*/
  public static final String OPT_USER_POSITION = "userPosition";
  /** 操作者岗位编码*/
  public static final String OPT_USER_POSITION_CODE = "userPositionCode";
  /** 操作者岗位状态*/
  public static final String OPT_USER_POSITION_STATUS = "userPositionStatus";


  /** 当前用户所在组织机构*/
  public static final String OPT_CUR_ORGS = "curOrgs";
  /** 当前用户所在上级组织机构*/
  public static final String OPT_PARENT_ORGS = "parentOrgs";
  /** 当前用户所在上级所有组织机构*/
  public static final String OPT_PARENT_ALL_ORGS = "parentAllOrgs";
  /** 当前用户所在下级组织机构*/
  public static final String OPT_CHILDREN_ORGS = "childrenOrgs";
  /** 当前用户所在下所有级组织机构*/
  public static final String OPT_CHILDREN_ALL_ORGS = "childrenAllOrgs";


  /** 操作者所在用户组*/
  public static final String OPT_USER_GROUP = "userGroup";
  /** 操作者所属角色*/
  public static final String OPT_USER_ROLE = "userRole";



  /** 当前时间（当前月）*/
  public static final String NOW_DATE_MONTH = "nowDateMonth";
  /** 当前时间（当前日）*/
  public static final String NOW_DATE_DAY = "nowDateDay";
  /** 当前时间（精确到秒）*/
  public static final String NOW_DATE_SECOND = "nowDateSecond";
  /** 当前时间（精确到分）*/
  public static final String NOW_DATE_MINUTE = "nowDateMinute";


  /** 当前操作者登录时间*/
  public static final String CURRENT_USER_LOGIN_TIME = "currentUserLoginTime";
  /** 当前操作者最后登出时间*/
  public static final String CURRENT_USER_LOG_OUT_TIME = "currentUserLogOutTime";

  /** 当前用户所在组织机构ID*/
  public static final String OPT_USER_ORG_ID = "userOrgId";
  /** 当前用户所在组织机构*/
  public static final String OPT_USER_ORG = "userOrg";
  /** 当前用户所在组织机构类型*/
  public static final String OPT_USER_ORG_TYPE = "userOrgType";
  /** 当前用户所在组织机构描述*/
  public static final String OPT_USER_ORG_DESC= "userOrgDesc";
  /** 当前用户所在组织机构状态*/
  public static final String OPT_USER_ORG_STATUS = "userOrgStatus";


}
